@@ -63,7 +63,7 @@ nb_pred_plot_args <- as.list(if (exists("plot.model.predict")) {
   formals(plot.model.predict)
 } else {
   formals(radiant.model:::plot.model.predict)
-} )
+})
 
 ## list of function inputs selected by user
 nb_pred_plot_inputs <- reactive({
@@ -124,7 +124,6 @@ observeEvent(input$dataset, {
   updateSelectInput(session = session, inputId = "nb_plots", selected = "none")
 })
 
-
 output$ui_nb_store_pred_name <- renderUI({
   req(input$nb_rvar)
   levs <- .get_data()[[input$nb_rvar]] %>%
@@ -145,31 +144,16 @@ output$ui_nb_predict_plot <- renderUI({
   predict_plot_controls("nb", vars_color = var_colors, init_color = ".class")
 })
 
-observe({
-  ## dep on most inputs
-  input$data_filter
-  input$show_filter
-  sapply(r_drop(names(nb_args)), function(x) input[[paste0("nb_", x)]])
-
-  ## notify user when the regression needs to be updated
-  ## based on https://stackoverflow.com/questions/45478521/listen-to-reactive-invalidation-in-shiny
-  if (pressed(input$nb_run)) {
-    if (is.null(input$nb_evar)) {
-      updateTabsetPanel(session, "tabs_nb ", selected = "Summary")
-      updateActionButton(session, "nb_run", "Estimate model", icon = icon("play"))
-    } else if (isTRUE(attr(nb_inputs, "observable")$.invalidated)) {
-      updateActionButton(session, "nb_run", "Re-estimate model", icon = icon("refresh", class = "fa-spin"))
-    } else {
-      updateActionButton(session, "nb_run", "Estimate model", icon = icon("play"))
-    }
-  }
-})
+## add a spinning refresh icon if the model needs to be (re)estimated
+run_refresh(nb_args, "nb", tabs = "tabs_nb", label = "Estimate model", relabel = "Re-estimate model")
 
 output$ui_nb <- renderUI({
   req(input$dataset)
   tagList(
-    wellPanel(
-      actionButton("nb_run", "Estimate model", width = "100%", icon = icon("play"), class = "btn-success")
+    conditionalPanel(condition = "input.tabs_nb == 'Summary'",
+      wellPanel(
+        actionButton("nb_run", "Estimate model", width = "100%", icon = icon("play"), class = "btn-success")
+      )
     ),
     wellPanel(
       conditionalPanel(
@@ -244,13 +228,16 @@ nb_plot <- reactive({
   if (is_empty(input$nb_plots, "none")) return()
   req(input$nb_lev)
 
-  n_vars <- length(.nb()$vars)
+  nb_res <- .nb()
+  if (is.character(nb_res)) return()
+
+  n_vars <- length(nb_res$vars)
   if (input$nb_plots == "correlations") {
     plot_height <- 150 * n_vars
     plot_width <- 150 * n_vars
   } else {
     if (input$nb_lev == "All levels") {
-      n_lev <- length(.nb()$lev) - 1
+      n_lev <- length(nb_res$lev) - 1
     } else {
       n_lev <- 2
     }
@@ -323,10 +310,12 @@ nb_available <- reactive({
 })
 
 .nb <- eventReactive(input$nb_run, {
-  withProgress(
-    message = "Estimating model", value = 1,
-    do.call(nb, nb_inputs())
-  )
+  withProgress(message = "Estimating model", value = 1, {
+    nbi <- nb_inputs()
+    nbi$envir <- r_data
+    do.call(nb, nbi)
+
+  })
 })
 
 .summary_nb <- reactive({
@@ -348,7 +337,10 @@ nb_available <- reactive({
   }
 
   withProgress(message = "Generating predictions", value = 1, {
-    do.call(predict, c(list(object = .nb()), nb_pred_inputs()))
+    nbi <- nb_pred_inputs()
+    nbi$object <- .nb()
+    nbi$envir <- r_data
+    do.call(predict, nbi)
   })
 })
 
@@ -394,7 +386,6 @@ nb_available <- reactive({
   if (input$nb_plots == "correlations") {
     capture_plot(do.call(plot, c(list(x = .nb()), nb_plot_inputs())))
   } else {
-    # if (input$nb_plots %in% c("correlations", "scatter")) req(input$nb_nrobs)
     withProgress(message = "Generating plots", value = 1, {
       do.call(plot, c(list(x = .nb()), nb_plot_inputs(), shiny = TRUE))
     })
